@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.1;
 
-our $VERSION = '1.775';
+our $VERSION = '1.776';
 
 use Exporter qw( import );
 
@@ -428,8 +428,10 @@ sub table_char_width { [
 [  0x1a7d,   0x1a7e, 1],
 [  0x1a7f,   0x1a7f, 0],
 [  0x1a80,   0x1aaf, 1],
-[  0x1ab0,   0x1ace, 0],
-[  0x1acf,   0x1aff, 1],
+[  0x1ab0,   0x1add, 0],
+[  0x1ade,   0x1adf, 1],
+[  0x1ae0,   0x1aeb, 0],
+[  0x1aec,   0x1aff, 1],
 [  0x1b00,   0x1b03, 0],
 [  0x1b04,   0x1b33, 1],
 [  0x1b34,   0x1b34, 0],
@@ -889,8 +891,8 @@ sub table_char_width { [
 [ 0x10d69,  0x10d6d, 0],
 [ 0x10d6e,  0x10eaa, 1],
 [ 0x10eab,  0x10eac, 0],
-[ 0x10ead,  0x10efb, 1],
-[ 0x10efc,  0x10eff, 0],
+[ 0x10ead,  0x10ef9, 1],
+[ 0x10efa,  0x10eff, 0],
 [ 0x10f00,  0x10f45, 1],
 [ 0x10f46,  0x10f50, 0],
 [ 0x10f51,  0x10f81, 1],
@@ -1043,7 +1045,13 @@ sub table_char_width { [
 [ 0x11a8a,  0x11a96, 0],
 [ 0x11a97,  0x11a97, 1],
 [ 0x11a98,  0x11a99, 0],
-[ 0x11a9a,  0x11c2f, 1],
+[ 0x11a9a,  0x11b5f, 1],
+[ 0x11b60,  0x11b60, 0],
+[ 0x11b61,  0x11b61, 1],
+[ 0x11b62,  0x11b64, 0],
+[ 0x11b65,  0x11b65, 1],
+[ 0x11b66,  0x11b66, 0],
+[ 0x11b67,  0x11c2f, 1],
 [ 0x11c30,  0x11c36, 0],
 [ 0x11c37,  0x11c37, 1],
 [ 0x11c38,  0x11c3d, 0],
@@ -1105,14 +1113,14 @@ sub table_char_width { [
 [ 0x16fe0,  0x16fe3, 2],
 [ 0x16fe4,  0x16fe4, 0],
 [ 0x16fe5,  0x16fef, 1],
-[ 0x16ff0,  0x16ff1, 2],
-[ 0x16ff2,  0x16fff, 1],
-[ 0x17000,  0x187f7, 2],
-[ 0x187f8,  0x187ff, 1],
-[ 0x18800,  0x18cd5, 2],
+[ 0x16ff0,  0x16ff6, 2],
+[ 0x16ff7,  0x16fff, 1],
+[ 0x17000,  0x18cd5, 2],
 [ 0x18cd6,  0x18cfe, 1],
-[ 0x18cff,  0x18d08, 2],
-[ 0x18d09,  0x1afef, 1],
+[ 0x18cff,  0x18d1e, 2],
+[ 0x18d1f,  0x18d7f, 1],
+[ 0x18d80,  0x18df2, 2],
+[ 0x18df3,  0x1afef, 1],
 [ 0x1aff0,  0x1aff3, 2],
 [ 0x1aff4,  0x1aff4, 1],
 [ 0x1aff5,  0x1affb, 2],
@@ -1186,7 +1194,15 @@ sub table_char_width { [
 [ 0x1e4ec,  0x1e4ef, 0],
 [ 0x1e4f0,  0x1e5ed, 1],
 [ 0x1e5ee,  0x1e5ef, 0],
-[ 0x1e5f0,  0x1e8cf, 1],
+[ 0x1e5f0,  0x1e6e2, 1],
+[ 0x1e6e3,  0x1e6e3, 0],
+[ 0x1e6e4,  0x1e6e5, 1],
+[ 0x1e6e6,  0x1e6e6, 0],
+[ 0x1e6e7,  0x1e6ed, 1],
+[ 0x1e6ee,  0x1e6ef, 0],
+[ 0x1e6f0,  0x1e6f4, 1],
+[ 0x1e6f5,  0x1e6f5, 0],
+[ 0x1e6f6,  0x1e8cf, 1],
 [ 0x1e8d0,  0x1e8d6, 0],
 [ 0x1e8d7,  0x1e943, 1],
 [ 0x1e944,  0x1e94a, 0],
@@ -1255,8 +1271,8 @@ sub table_char_width { [
 [ 0x1f6cd,  0x1f6cf, 1],
 [ 0x1f6d0,  0x1f6d2, 2],
 [ 0x1f6d3,  0x1f6d4, 1],
-[ 0x1f6d5,  0x1f6d7, 2],
-[ 0x1f6d8,  0x1f6db, 1],
+[ 0x1f6d5,  0x1f6d8, 2],
+[ 0x1f6d9,  0x1f6db, 1],
 [ 0x1f6dc,  0x1f6df, 2],
 [ 0x1f6e0,  0x1f6ea, 1],
 [ 0x1f6eb,  0x1f6ec, 2],
@@ -1275,15 +1291,17 @@ sub table_char_width { [
 [ 0x1fa00,  0x1fa6f, 1],
 [ 0x1fa70,  0x1fa7c, 2],
 [ 0x1fa7d,  0x1fa7f, 1],
-[ 0x1fa80,  0x1fa89, 2],
-[ 0x1fa8a,  0x1fa8e, 1],
-[ 0x1fa8f,  0x1fac6, 2],
-[ 0x1fac7,  0x1facd, 1],
-[ 0x1face,  0x1fadc, 2],
+[ 0x1fa80,  0x1fa8a, 2],
+[ 0x1fa8b,  0x1fa8d, 1],
+[ 0x1fa8e,  0x1fac6, 2],
+[ 0x1fac7,  0x1fac7, 1],
+[ 0x1fac8,  0x1fac8, 2],
+[ 0x1fac9,  0x1facc, 1],
+[ 0x1facd,  0x1fadc, 2],
 [ 0x1fadd,  0x1fade, 1],
-[ 0x1fadf,  0x1fae9, 2],
-[ 0x1faea,  0x1faef, 1],
-[ 0x1faf0,  0x1faf8, 2],
+[ 0x1fadf,  0x1faea, 2],
+[ 0x1faeb,  0x1faee, 1],
+[ 0x1faef,  0x1faf8, 2],
 [ 0x1faf9,  0x1ffff, 1],
 [ 0x20000,  0x2fffd, 2],
 [ 0x2fffe,  0x2ffff, 1],
@@ -1299,8 +1317,7 @@ sub table_char_width { [
 [ 0xffffe,  0xfffff, 1],
 [0x100000, 0x10fffd, 2],
 [0x10fffe, 0x10ffff, 1],
-]
-}
+] }
 
 
 1;
